@@ -54,3 +54,5 @@ fi
 
 # copy our rebar
 cp bin/rebar ${REL_DIR}/bin/rebar
+cp bin/rebar3 ${REL_DIR}/bin/rebar3
+cp bin/erlfmt ${REL_DIR}/bin/erlfmt
