@@ -33,7 +33,6 @@ import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
-import java.util.stream.Stream;
 import org.apache.couchdb.nouveau.api.IndexDefinition;
 import org.apache.couchdb.nouveau.lucene9.Lucene9AnalyzerFactory;
 import org.apache.couchdb.nouveau.lucene9.Lucene9Index;
@@ -250,35 +249,49 @@ public final class IndexManager implements Managed {
     }
 
     public void deleteAll(final String path, final List<String> exclusions) throws IOException {
-        LOGGER.info("deleting indexes below {} (excluding {})", path, exclusions == null ? "nothing" : exclusions);
+        LOGGER.info(
+                "deleting indexes matching {} (excluding {})",
+                path,
+                exclusions == null || exclusions.isEmpty() ? "nothing" : exclusions);
+        var parts = path.split("/");
+        deleteAll(rootDir, parts, 0, exclusions);
+    }
 
-        final Path indexRootPath = indexRootPath(path);
-        if (!indexRootPath.toFile().exists()) {
+    private void deleteAll(final Path path, final String[] parts, final int index, final List<String> exclusions)
+            throws IOException {
+        // End of the path
+        if (index == parts.length - 1) {
+            try (var stream = Files.newDirectoryStream(path, parts[index])) {
+                stream.forEach(p -> {
+                    if (exclusions != null && exclusions.indexOf(p.getFileName().toString()) != -1) {
+                        return;
+                    }
+                    final String relativeName = rootDir.relativize(p).toString();
+                    try {
+                        deleteIndex(relativeName);
+                    } catch (final IOException | InterruptedException e) {
+                        LOGGER.error("Exception deleting {}", p, e);
+                    }
+                    // Clean any newly empty directories.
+                    do {
+                        final File f = p.toFile();
+                        if (f.isDirectory() && f.list().length == 0) {
+                            f.delete();
+                        }
+                    } while ((p = p.getParent()) != null && !rootDir.equals(p));
+                });
+            }
             return;
         }
-        Stream<Path> stream = Files.find(indexRootPath, 100, (p, attr) -> attr.isDirectory() && isIndex(p));
-        try {
-            stream.forEach((p) -> {
-                final String relativeToExclusions = indexRootPath.relativize(p).toString();
-                if (exclusions != null && exclusions.indexOf(relativeToExclusions) != -1) {
-                    return;
-                }
-                final String relativeName = rootDir.relativize(p).toString();
+        // Recurse
+        try (var stream = Files.newDirectoryStream(path, parts[index])) {
+            stream.forEach(p -> {
                 try {
-                    deleteIndex(relativeName);
-                } catch (final IOException | InterruptedException e) {
-                    LOGGER.error("Exception deleting {}", p, e);
+                    deleteAll(p, parts, index + 1, exclusions);
+                } catch (IOException e) {
+                    LOGGER.warn("Exception during delete of " + rootDir.relativize(p), e);
                 }
-                // Clean any newly empty directories.
-                do {
-                    final File f = p.toFile();
-                    if (f.isDirectory() && f.list().length == 0) {
-                        f.delete();
-                    }
-                } while ((p = p.getParent()) != null && !rootDir.equals(p));
             });
-        } finally {
-            stream.close();
         }
     }
 
