@@ -13,7 +13,6 @@
 -module(config_notifier).
 
 -behaviour(gen_event).
--vsn(1).
 
 %% Public interface
 -export([subscribe/1]).
@@ -24,9 +23,7 @@
     init/1,
     handle_event/2,
     handle_call/2,
-    handle_info/2,
-    terminate/2,
-    code_change/3
+    handle_info/2
 ]).
 
 subscribe(Subscription) ->
@@ -55,12 +52,6 @@ handle_call(_Request, St) ->
 handle_info(_Info, St) ->
     {ok, St}.
 
-terminate(_Reason, {_Subscriber, _Subscription}) ->
-    ok.
-
-code_change(_OldVsn, St, _Extra) ->
-    {ok, St}.
-
 maybe_notify(Event, Subscriber, all) ->
     Subscriber ! Event;
 maybe_notify({config_change, Sec, Key, _, _} = Event, Subscriber, Subscription) ->
