@@ -700,15 +700,15 @@ should_remove_handler_when_pid_exits({_Apps, Pid}) ->
 
         % Monitor the config_listener_mon process
         {monitored_by, [Mon]} = process_info(Pid, monitored_by),
-        MonRef = erlang:monitor(process, Mon),
+        MonRef = monitor(process, Mon),
 
         % Kill the process synchronously
-        PidRef = erlang:monitor(process, Pid),
+        PidRef = monitor(process, Pid),
         exit(Pid, kill),
         receive
             {'DOWN', PidRef, _, _, _} -> ok
         after ?TIMEOUT ->
-            erlang:error({timeout, config_listener_death})
+            error({timeout, config_listener_death})
         end,
 
         % Wait for the config_listener_mon process to
@@ -716,7 +716,7 @@ should_remove_handler_when_pid_exits({_Apps, Pid}) ->
         receive
             {'DOWN', MonRef, _, _, normal} -> ok
         after ?TIMEOUT ->
-            erlang:error({timeout, config_listener_mon_death})
+            error({timeout, config_listener_mon_death})
         end,
 
         ?assertEqual(0, n_handlers())
@@ -728,7 +728,7 @@ should_stop_monitor_on_error({_Apps, Pid}) ->
 
         % Monitor the config_listener_mon process
         {monitored_by, [Mon]} = process_info(Pid, monitored_by),
-        MonRef = erlang:monitor(process, Mon),
+        MonRef = monitor(process, Mon),
 
         % Have the process throw an error
         ?assertEqual(ok, config:set("throw_error", "foo", "bar", false)),
@@ -742,7 +742,7 @@ should_stop_monitor_on_error({_Apps, Pid}) ->
         receive
             {'DOWN', MonRef, _, _, shutdown} -> ok
         after ?TIMEOUT ->
-            erlang:error({timeout, config_listener_mon_shutdown})
+            error({timeout, config_listener_mon_shutdown})
         end,
 
         ?assertEqual(0, n_handlers())
@@ -784,7 +784,7 @@ should_unsubscribe_when_subscriber_gone(_Subscription, {_Apps, Pid}) ->
         ?assert(is_process_alive(Pid)),
 
         % Monitor subscriber process
-        MonRef = erlang:monitor(process, Pid),
+        MonRef = monitor(process, Pid),
 
         exit(Pid, kill),
 
@@ -792,7 +792,7 @@ should_unsubscribe_when_subscriber_gone(_Subscription, {_Apps, Pid}) ->
         receive
             {'DOWN', MonRef, _, _, _} -> ok
         after ?TIMEOUT ->
-            erlang:error({timeout, config_notifier_shutdown})
+            error({timeout, config_notifier_shutdown})
         end,
 
         ?assertNot(is_process_alive(Pid)),
@@ -1015,7 +1015,7 @@ wait_config_get(Sec, Key, Val) ->
 
 spawn_config_listener() ->
     Self = self(),
-    Pid = erlang:spawn(fun() ->
+    Pid = spawn(fun() ->
         ok = config:listen_for_changes(?MODULE, {self(), undefined}),
         Self ! registered,
         loop(undefined)
@@ -1023,13 +1023,13 @@ spawn_config_listener() ->
     receive
         registered -> ok
     after ?TIMEOUT ->
-        erlang:error({timeout, config_handler_register})
+        error({timeout, config_handler_register})
     end,
     Pid.
 
 spawn_config_notifier(Subscription) ->
     Self = self(),
-    Pid = erlang:spawn(fun() ->
+    Pid = spawn(fun() ->
         ok = config:subscribe_for_changes(Subscription),
         Self ! registered,
         loop(undefined)
@@ -1037,7 +1037,7 @@ spawn_config_notifier(Subscription) ->
     receive
         registered -> ok
     after ?TIMEOUT ->
-        erlang:error({timeout, config_handler_register})
+        error({timeout, config_handler_register})
     end,
     Pid.
 
@@ -1050,7 +1050,7 @@ loop(undefined) ->
         {get_msg, _, _} = Msg ->
             loop(Msg);
         Msg ->
-            erlang:error({invalid_message, Msg})
+            error({invalid_message, Msg})
     end;
 loop({get_msg, From, Ref}) ->
     receive
@@ -1059,7 +1059,7 @@ loop({get_msg, From, Ref}) ->
         {config_change, _, _, _, _} = Msg ->
             From ! {Ref, Msg};
         Msg ->
-            erlang:error({invalid_message, Msg})
+            error({invalid_message, Msg})
     end,
     loop(undefined);
 loop({config_msg, _} = Msg) ->
@@ -1067,17 +1067,17 @@ loop({config_msg, _} = Msg) ->
         {get_msg, From, Ref} ->
             From ! {Ref, Msg};
         Msg ->
-            erlang:error({invalid_message, Msg})
+            error({invalid_message, Msg})
     end,
     loop(undefined).
 
 getmsg(Pid) ->
-    Ref = erlang:make_ref(),
+    Ref = make_ref(),
     Pid ! {get_msg, self(), Ref},
     receive
         {Ref, {config_msg, Msg}} -> Msg
     after ?TIMEOUT ->
-        erlang:error({timeout, config_msg})
+        error({timeout, config_msg})
     end.
 
 n_handlers() ->
@@ -1112,7 +1112,7 @@ wait_process_restart(Name, Timeout, Delay, Started, _Prev) ->
     end.
 
 stop_sync(Pid, Timeout) when is_pid(Pid) ->
-    MRef = erlang:monitor(process, Pid),
+    MRef = monitor(process, Pid),
     try
         begin
             catch unlink(Pid),
@@ -1125,7 +1125,7 @@ stop_sync(Pid, Timeout) when is_pid(Pid) ->
             end
         end
     after
-        erlang:demonitor(MRef, [flush])
+        demonitor(MRef, [flush])
     end;
 stop_sync(_, _) ->
     error(badarg).
