@@ -14,11 +14,30 @@
 
 -export([open/2, open/3, query_modify/4, add/2, add_remove/3]).
 -export([fold/4, full_reduce/1, final_reduce/2, size/1, foldl/3, foldl/4]).
--export([fold_reduce/4, lookup/2, get_state/1, set_options/2]).
+-export([fold_reduce/4, lookup/2, set_options/2]).
+-export([is_btree/1, get_state/1, get_fd/1, get_reduce_fun/1]).
 -export([extract/2, assemble/3, less/3]).
 
 -include_lib("couch/include/couch_db.hrl").
 
+-define(DEFAULT_CHUNK_SIZE, 1279).
+
+% For the btree cache, the priority of the root node will be
+% this value. The priority is roughly how many cleanup interval
+% (second) they'll survive without any updates in the cache
+-define(ROOT_NODE_CACHE_PRIORITY, 8).
+
+-record(btree, {
+    fd,
+    root,
+    extract_kv,
+    assemble_kv,
+    less,
+    reduce = nil,
+    compression = ?DEFAULT_COMPRESSION,
+    cache_depth = 0
+}).
+
 -define(FILL_RATIO, 0.5).
 
 extract(#btree{extract_kv = undefined}, Value) ->
@@ -31,11 +50,18 @@ assemble(#btree{assemble_kv = undefined}, Key, Value) ->
 assemble(#btree{assemble_kv = Assemble}, Key, Value) ->
     Assemble(Key, Value).
 
+-compile({inline, [less/3]}).
 less(#btree{less = undefined}, A, B) ->
     A < B;
 less(#btree{less = Less}, A, B) ->
     Less(A, B).
 
+-compile({inline, [less_eq/3]}).
+less_eq(#btree{less = undefined}, A, B) ->
+    A =< B;
+less_eq(#btree{less = Less}, A, B) ->
+    Less(A, B) orelse not Less(B, A).
+
 % pass in 'nil' for State if a new Btree.
 open(State, Fd) ->
     {ok, #btree{root = State, fd = Fd}}.
@@ -51,14 +77,27 @@ set_options(Bt, [{less, Less} | Rest]) ->
 set_options(Bt, [{reduce, Reduce} | Rest]) ->
     set_options(Bt#btree{reduce = Reduce}, Rest);
 set_options(Bt, [{compression, Comp} | Rest]) ->
-    set_options(Bt#btree{compression = Comp}, Rest).
+    set_options(Bt#btree{compression = Comp}, Rest);
+set_options(Bt, [{cache_depth, Depth} | Rest]) when is_integer(Depth) ->
+    set_options(Bt#btree{cache_depth = Depth}, Rest).
 
 open(State, Fd, Options) ->
     {ok, set_options(#btree{root = State, fd = Fd}, Options)}.
 
+is_btree(#btree{}) ->
+    true;
+is_btree(_) ->
+    false.
+
 get_state(#btree{root = Root}) ->
     Root.
 
+get_fd(#btree{fd = Fd}) ->
+    Fd.
+
+get_reduce_fun(#btree{reduce = Reduce}) ->
+    Reduce.
+
 final_reduce(#btree{reduce = Reduce}, Val) ->
     final_reduce(Reduce, Val);
 final_reduce(Reduce, {[], []}) ->
@@ -89,7 +128,8 @@ fold_reduce(#btree{root = Root} = Bt, Fun, Acc, Options) ->
                 [],
                 KeyGroupFun,
                 Fun,
-                Acc
+                Acc,
+                0
             ),
         if
             GroupedKey2 == undefined ->
@@ -236,7 +276,8 @@ fold(#btree{root = Root} = Bt, Fun, Acc, Options) ->
                     InRange,
                     Dir,
                     convert_fun_arity(Fun),
-                    Acc
+                    Acc,
+                    0
                 );
             StartKey ->
                 stream_node(
@@ -247,7 +288,8 @@ fold(#btree{root = Root} = Bt, Fun, Acc, Options) ->
                     InRange,
                     Dir,
                     convert_fun_arity(Fun),
-                    Acc
+                    Acc,
+                    0
                 )
         end,
     case Result of
@@ -276,6 +318,11 @@ query_modify(Bt, LookupKeys, InsertValues, RemoveKeys) ->
     ),
     RemoveActions = [{remove, Key, nil} || Key <- RemoveKeys],
     FetchActions = [{fetch, Key, nil} || Key <- LookupKeys],
+
+    UniqueFun = fun({Op, A, _}, {Op, B, _}) -> less_eq(Bt, A, B) end,
+    InsertActions1 = lists:usort(UniqueFun, InsertActions),
+    RemoveActions1 = lists:usort(UniqueFun, RemoveActions),
+
     SortFun =
         fun({OpA, A, _}, {OpB, B, _}) ->
             case A == B of
@@ -284,8 +331,8 @@ query_modify(Bt, LookupKeys, InsertValues, RemoveKeys) ->
                 false -> less(Bt, A, B)
             end
         end,
-    Actions = lists:sort(SortFun, lists:append([InsertActions, RemoveActions, FetchActions])),
-    {ok, KeyPointers, QueryResults} = modify_node(Bt, Root, Actions, []),
+    Actions = lists:sort(SortFun, lists:append([InsertActions1, RemoveActions1, FetchActions])),
+    {ok, KeyPointers, QueryResults} = modify_node(Bt, Root, Actions, [], 0),
     {ok, NewRoot} = complete_root(Bt, KeyPointers),
     {ok, QueryResults, Bt#btree{root = NewRoot}}.
 
@@ -301,64 +348,87 @@ lookup(#btree{root = Root, less = Less} = Bt, Keys) ->
             undefined -> lists:sort(Keys);
             _ -> lists:sort(Less, Keys)
         end,
-    {ok, SortedResults} = lookup(Bt, Root, SortedKeys),
+    {ok, SortedResults} = lookup(Bt, Root, SortedKeys, 0),
     % We want to return the results in the same order as the keys were input
     % but we may have changed the order when we sorted. So we need to put the
     % order back into the results.
     couch_util:reorder_results(Keys, SortedResults).
 
-lookup(_Bt, nil, Keys) ->
+lookup(_Bt, nil, Keys, _Depth) ->
     {ok, [{Key, not_found} || Key <- Keys]};
-lookup(Bt, Node, Keys) ->
+lookup(Bt, Node, Keys, Depth0) ->
+    Depth = Depth0 + 1,
     Pointer = element(1, Node),
-    {NodeType, NodeList} = get_node(Bt, Pointer),
+    {NodeType, NodeList} = get_node(Bt, Pointer, Depth),
     case NodeType of
         kp_node ->
-            lookup_kpnode(Bt, list_to_tuple(NodeList), 1, Keys, []);
+            lookup_kpnode(Bt, list_to_tuple(NodeList), 1, Keys, [], Depth);
         kv_node ->
-            lookup_kvnode(Bt, list_to_tuple(NodeList), 1, Keys, [])
+            lookup_kvnode(Bt, list_to_tuple(NodeList), 1, Keys, [], Depth)
     end.
 
-lookup_kpnode(_Bt, _NodeTuple, _LowerBound, [], Output) ->
+lookup_kpnode(_Bt, _NodeTuple, _LowerBound, [], Output, _Depth) ->
     {ok, lists:reverse(Output)};
-lookup_kpnode(_Bt, NodeTuple, LowerBound, Keys, Output) when tuple_size(NodeTuple) < LowerBound ->
+lookup_kpnode(_Bt, NodeTuple, LowerBound, Keys, Output, _Depth) when
+    tuple_size(NodeTuple) < LowerBound
+->
     {ok, lists:reverse(Output, [{Key, not_found} || Key <- Keys])};
-lookup_kpnode(Bt, NodeTuple, LowerBound, [FirstLookupKey | _] = LookupKeys, Output) ->
+lookup_kpnode(Bt, NodeTuple, LowerBound, [FirstLookupKey | _] = LookupKeys, Output, Depth) ->
     N = find_first_gteq(Bt, NodeTuple, LowerBound, tuple_size(NodeTuple), FirstLookupKey),
     {Key, PointerInfo} = element(N, NodeTuple),
     SplitFun = fun(LookupKey) -> not less(Bt, Key, LookupKey) end,
     case lists:splitwith(SplitFun, LookupKeys) of
         {[], GreaterQueries} ->
-            lookup_kpnode(Bt, NodeTuple, N + 1, GreaterQueries, Output);
+            lookup_kpnode(Bt, NodeTuple, N + 1, GreaterQueries, Output, Depth);
         {LessEqQueries, GreaterQueries} ->
-            {ok, Results} = lookup(Bt, PointerInfo, LessEqQueries),
-            lookup_kpnode(Bt, NodeTuple, N + 1, GreaterQueries, lists:reverse(Results, Output))
+            {ok, Results} = lookup(Bt, PointerInfo, LessEqQueries, Depth),
+            lookup_kpnode(
+                Bt, NodeTuple, N + 1, GreaterQueries, lists:reverse(Results, Output), Depth
+            )
     end.
 
-lookup_kvnode(_Bt, _NodeTuple, _LowerBound, [], Output) ->
+lookup_kvnode(_Bt, _NodeTuple, _LowerBound, [], Output, _Depth) ->
     {ok, lists:reverse(Output)};
-lookup_kvnode(_Bt, NodeTuple, LowerBound, Keys, Output) when tuple_size(NodeTuple) < LowerBound ->
+lookup_kvnode(_Bt, NodeTuple, LowerBound, Keys, Output, _Depth) when
+    tuple_size(NodeTuple) < LowerBound
+->
     % keys not found
     {ok, lists:reverse(Output, [{Key, not_found} || Key <- Keys])};
-lookup_kvnode(Bt, NodeTuple, LowerBound, [LookupKey | RestLookupKeys], Output) ->
+lookup_kvnode(Bt, NodeTuple, LowerBound, [LookupKey | RestLookupKeys], Output, Depth) ->
     N = find_first_gteq(Bt, NodeTuple, LowerBound, tuple_size(NodeTuple), LookupKey),
     {Key, Value} = element(N, NodeTuple),
     case less(Bt, LookupKey, Key) of
         true ->
             % LookupKey is less than Key
-            lookup_kvnode(Bt, NodeTuple, N, RestLookupKeys, [{LookupKey, not_found} | Output]);
+            lookup_kvnode(
+                Bt, NodeTuple, N, RestLookupKeys, [{LookupKey, not_found} | Output], Depth
+            );
         false ->
             case less(Bt, Key, LookupKey) of
                 true ->
                     % LookupKey is greater than Key
-                    lookup_kvnode(Bt, NodeTuple, N + 1, RestLookupKeys, [
-                        {LookupKey, not_found} | Output
-                    ]);
+                    lookup_kvnode(
+                        Bt,
+                        NodeTuple,
+                        N + 1,
+                        RestLookupKeys,
+                        [
+                            {LookupKey, not_found} | Output
+                        ],
+                        Depth
+                    );
                 false ->
                     % LookupKey is equal to Key
-                    lookup_kvnode(Bt, NodeTuple, N, RestLookupKeys, [
-                        {LookupKey, {ok, assemble(Bt, LookupKey, Value)}} | Output
-                    ])
+                    lookup_kvnode(
+                        Bt,
+                        NodeTuple,
+                        N,
+                        RestLookupKeys,
+                        [
+                            {LookupKey, {ok, assemble(Bt, LookupKey, Value)}} | Output
+                        ],
+                        Depth
+                    )
             end
     end.
 
@@ -407,32 +477,29 @@ chunkify([InElement | RestInList], ChunkThreshold, OutList, OutListSize, OutputC
 
 -compile({inline, [get_chunk_size/0]}).
 get_chunk_size() ->
-    try
-        list_to_integer(config:get("couchdb", "btree_chunk_size", "1279"))
-    catch
-        error:badarg ->
-            1279
-    end.
+    config:get_integer("couchdb", "btree_chunk_size", ?DEFAULT_CHUNK_SIZE).
 
-modify_node(Bt, RootPointerInfo, Actions, QueryOutput) ->
+modify_node(Bt, RootPointerInfo, Actions, QueryOutput, Depth0) ->
+    Depth = Depth0 + 1,
     {NodeType, NodeList} =
         case RootPointerInfo of
             nil ->
                 {kv_node, []};
             _Tuple ->
                 Pointer = element(1, RootPointerInfo),
-                get_node(Bt, Pointer)
+                get_node(Bt, Pointer, Depth)
         end,
     NodeTuple = list_to_tuple(NodeList),
 
     {ok, NewNodeList, QueryOutput2} =
         case NodeType of
-            kp_node -> modify_kpnode(Bt, NodeTuple, 1, Actions, [], QueryOutput);
-            kv_node -> modify_kvnode(Bt, NodeTuple, 1, Actions, [], QueryOutput)
+            kp_node -> modify_kpnode(Bt, NodeTuple, 1, Actions, [], QueryOutput, Depth);
+            kv_node -> modify_kvnode(Bt, NodeTuple, 1, Actions, [], QueryOutput, Depth)
         end,
     case NewNodeList of
         % no nodes remain
         [] ->
+            reset_cache_usage(Bt, RootPointerInfo, Depth),
             {ok, [], QueryOutput2};
         % nothing changed
         NodeList ->
@@ -444,6 +511,7 @@ modify_node(Bt, RootPointerInfo, Actions, QueryOutput) ->
                     nil ->
                         write_node(Bt, NodeType, NewNodeList);
                     _ ->
+                        reset_cache_usage(Bt, RootPointerInfo, Depth),
                         {LastKey, _LastValue} = element(tuple_size(NodeTuple), NodeTuple),
                         OldNode = {LastKey, RootPointerInfo},
                         write_node(Bt, OldNode, NodeType, NodeList, NewNodeList)
@@ -470,7 +538,30 @@ reduce_tree_size(kp_node, _NodeSize, [{_K, {_P, _Red, nil}} | _]) ->
 reduce_tree_size(kp_node, NodeSize, [{_K, {_P, _Red, Sz}} | NodeList]) ->
     reduce_tree_size(kp_node, NodeSize + Sz, NodeList).
 
-get_node(#btree{fd = Fd}, NodePos) ->
+reset_cache_usage(_, nil, _Depth) ->
+    ok;
+reset_cache_usage(#btree{cache_depth = Max}, _, Depth) when Depth > Max ->
+    ok;
+reset_cache_usage(#btree{fd = Fd}, RootPointerInfo, _Depth) ->
+    Pointer = element(1, RootPointerInfo),
+    couch_bt_engine_cache:reset({Fd, Pointer}).
+
+get_node(#btree{fd = Fd, cache_depth = Max}, NodePos, Depth) when Depth =< Max ->
+    case couch_bt_engine_cache:lookup({Fd, NodePos}) of
+        undefined ->
+            {ok, {NodeType, NodeList}} = couch_file:pread_term(Fd, NodePos),
+            case NodeType of
+                kp_node ->
+                    Priority = max(1, ?ROOT_NODE_CACHE_PRIORITY - Depth),
+                    couch_bt_engine_cache:insert({Fd, NodePos}, NodeList, Priority);
+                kv_node ->
+                    ok
+            end,
+            {NodeType, NodeList};
+        NodeList ->
+            {kp_node, NodeList}
+    end;
+get_node(#btree{fd = Fd}, NodePos, _Depth) ->
     {ok, {NodeType, NodeList}} = couch_file:pread_term(Fd, NodePos),
     {NodeType, NodeList}.
 
@@ -546,9 +637,9 @@ old_list_is_prefix([KV | Rest1], [KV | Rest2], Acc) ->
 old_list_is_prefix(_OldList, _NewList, _Acc) ->
     false.
 
-modify_kpnode(Bt, {}, _LowerBound, Actions, [], QueryOutput) ->
-    modify_node(Bt, nil, Actions, QueryOutput);
-modify_kpnode(_Bt, NodeTuple, LowerBound, [], ResultNode, QueryOutput) ->
+modify_kpnode(Bt, {}, _LowerBound, Actions, [], QueryOutput, Depth) ->
+    modify_node(Bt, nil, Actions, QueryOutput, Depth);
+modify_kpnode(_Bt, NodeTuple, LowerBound, [], ResultNode, QueryOutput, _Depth) ->
     {ok,
         lists:reverse(
             ResultNode,
@@ -566,7 +657,8 @@ modify_kpnode(
     LowerBound,
     [{_, FirstActionKey, _} | _] = Actions,
     ResultNode,
-    QueryOutput
+    QueryOutput,
+    Depth
 ) ->
     Sz = tuple_size(NodeTuple),
     N = find_first_gteq(Bt, NodeTuple, LowerBound, Sz, FirstActionKey),
@@ -575,7 +667,7 @@ modify_kpnode(
             % perform remaining actions on last node
             {_, PointerInfo} = element(Sz, NodeTuple),
             {ok, ChildKPs, QueryOutput2} =
-                modify_node(Bt, PointerInfo, Actions, QueryOutput),
+                modify_node(Bt, PointerInfo, Actions, QueryOutput, Depth),
             NodeList = lists:reverse(
                 ResultNode,
                 bounded_tuple_to_list(
@@ -593,7 +685,7 @@ modify_kpnode(
             end,
             {LessEqQueries, GreaterQueries} = lists:splitwith(SplitFun, Actions),
             {ok, ChildKPs, QueryOutput2} =
-                modify_node(Bt, PointerInfo, LessEqQueries, QueryOutput),
+                modify_node(Bt, PointerInfo, LessEqQueries, QueryOutput, Depth),
             ResultNode2 = lists:reverse(
                 ChildKPs,
                 bounded_tuple_to_revlist(
@@ -603,7 +695,7 @@ modify_kpnode(
                     ResultNode
                 )
             ),
-            modify_kpnode(Bt, NodeTuple, N + 1, GreaterQueries, ResultNode2, QueryOutput2)
+            modify_kpnode(Bt, NodeTuple, N + 1, GreaterQueries, ResultNode2, QueryOutput2, Depth)
     end.
 
 bounded_tuple_to_revlist(_Tuple, Start, End, Tail) when Start > End ->
@@ -631,7 +723,7 @@ find_first_gteq(Bt, Tuple, Start, End, Key) ->
             find_first_gteq(Bt, Tuple, Start, Mid, Key)
     end.
 
-modify_kvnode(_Bt, NodeTuple, LowerBound, [], ResultNode, QueryOutput) ->
+modify_kvnode(_Bt, NodeTuple, LowerBound, [], ResultNode, QueryOutput, _Depth) ->
     {ok,
         lists:reverse(
             ResultNode, bounded_tuple_to_list(NodeTuple, LowerBound, tuple_size(NodeTuple), [])
@@ -643,7 +735,8 @@ modify_kvnode(
     LowerBound,
     [{ActionType, ActionKey, ActionValue} | RestActions],
     ResultNode,
-    QueryOutput
+    QueryOutput,
+    Depth
 ) when LowerBound > tuple_size(NodeTuple) ->
     case ActionType of
         insert ->
@@ -653,16 +746,25 @@ modify_kvnode(
                 LowerBound,
                 RestActions,
                 [{ActionKey, ActionValue} | ResultNode],
-                QueryOutput
+                QueryOutput,
+                Depth
             );
         remove ->
             % just drop the action
-            modify_kvnode(Bt, NodeTuple, LowerBound, RestActions, ResultNode, QueryOutput);
+            modify_kvnode(Bt, NodeTuple, LowerBound, RestActions, ResultNode, QueryOutput, Depth);
         fetch ->
             % the key/value must not exist in the tree
-            modify_kvnode(Bt, NodeTuple, LowerBound, RestActions, ResultNode, [
-                {not_found, {ActionKey, nil}} | QueryOutput
-            ])
+            modify_kvnode(
+                Bt,
+                NodeTuple,
+                LowerBound,
+                RestActions,
+                ResultNode,
+                [
+                    {not_found, {ActionKey, nil}} | QueryOutput
+                ],
+                Depth
+            )
     end;
 modify_kvnode(
     Bt,
@@ -670,7 +772,8 @@ modify_kvnode(
     LowerBound,
     [{ActionType, ActionKey, ActionValue} | RestActions],
     AccNode,
-    QueryOutput
+    QueryOutput,
+    Depth
 ) ->
     N = find_first_gteq(Bt, NodeTuple, LowerBound, tuple_size(NodeTuple), ActionKey),
     {Key, Value} = element(N, NodeTuple),
@@ -686,16 +789,25 @@ modify_kvnode(
                         N,
                         RestActions,
                         [{ActionKey, ActionValue} | ResultNode],
-                        QueryOutput
+                        QueryOutput,
+                        Depth
                     );
                 remove ->
                     % ActionKey is less than the Key, just drop the action
-                    modify_kvnode(Bt, NodeTuple, N, RestActions, ResultNode, QueryOutput);
+                    modify_kvnode(Bt, NodeTuple, N, RestActions, ResultNode, QueryOutput, Depth);
                 fetch ->
                     % ActionKey is less than the Key, the key/value must not exist in the tree
-                    modify_kvnode(Bt, NodeTuple, N, RestActions, ResultNode, [
-                        {not_found, {ActionKey, nil}} | QueryOutput
-                    ])
+                    modify_kvnode(
+                        Bt,
+                        NodeTuple,
+                        N,
+                        RestActions,
+                        ResultNode,
+                        [
+                            {not_found, {ActionKey, nil}} | QueryOutput
+                        ],
+                        Depth
+                    )
             end;
         false ->
             % ActionKey and Key are maybe equal.
@@ -709,18 +821,27 @@ modify_kvnode(
                                 N + 1,
                                 RestActions,
                                 [{ActionKey, ActionValue} | ResultNode],
-                                QueryOutput
+                                QueryOutput,
+                                Depth
                             );
                         remove ->
                             modify_kvnode(
-                                Bt, NodeTuple, N + 1, RestActions, ResultNode, QueryOutput
+                                Bt, NodeTuple, N + 1, RestActions, ResultNode, QueryOutput, Depth
                             );
                         fetch ->
                             % ActionKey is equal to the Key, insert into the QueryOuput, but re-process the node
                             % since an identical action key can follow it.
-                            modify_kvnode(Bt, NodeTuple, N, RestActions, ResultNode, [
-                                {ok, assemble(Bt, Key, Value)} | QueryOutput
-                            ])
+                            modify_kvnode(
+                                Bt,
+                                NodeTuple,
+                                N,
+                                RestActions,
+                                ResultNode,
+                                [
+                                    {ok, assemble(Bt, Key, Value)} | QueryOutput
+                                ],
+                                Depth
+                            )
                     end;
                 true ->
                     modify_kvnode(
@@ -729,7 +850,8 @@ modify_kvnode(
                         N + 1,
                         [{ActionType, ActionKey, ActionValue} | RestActions],
                         [{Key, Value} | ResultNode],
-                        QueryOutput
+                        QueryOutput,
+                        Depth
                     )
             end
     end.
@@ -745,7 +867,8 @@ reduce_stream_node(
     GroupedRedsAcc,
     _KeyGroupFun,
     _Fun,
-    Acc
+    Acc,
+    _Depth
 ) ->
     {ok, Acc, GroupedRedsAcc, GroupedKVsAcc, GroupedKey};
 reduce_stream_node(
@@ -759,10 +882,12 @@ reduce_stream_node(
     GroupedRedsAcc,
     KeyGroupFun,
     Fun,
-    Acc
+    Acc,
+    Depth0
 ) ->
+    Depth = Depth0 + 1,
     P = element(1, Node),
-    case get_node(Bt, P) of
+    case get_node(Bt, P, Depth) of
         {kp_node, NodeList} ->
             NodeList2 = adjust_dir(Dir, NodeList),
             reduce_stream_kp_node(
@@ -776,7 +901,8 @@ reduce_stream_node(
                 GroupedRedsAcc,
                 KeyGroupFun,
                 Fun,
-                Acc
+                Acc,
+                Depth
             );
         {kv_node, KVs} ->
             KVs2 = adjust_dir(Dir, KVs),
@@ -791,7 +917,8 @@ reduce_stream_node(
                 GroupedRedsAcc,
                 KeyGroupFun,
                 Fun,
-                Acc
+                Acc,
+                Depth
             )
     end.
 
@@ -806,7 +933,8 @@ reduce_stream_kv_node(
     GroupedRedsAcc,
     KeyGroupFun,
     Fun,
-    Acc
+    Acc,
+    Depth
 ) ->
     GTEKeyStartKVs =
         case KeyStart of
@@ -833,7 +961,8 @@ reduce_stream_kv_node(
         GroupedRedsAcc,
         KeyGroupFun,
         Fun,
-        Acc
+        Acc,
+        Depth
     ).
 
 reduce_stream_kv_node2(
@@ -844,7 +973,8 @@ reduce_stream_kv_node2(
     GroupedRedsAcc,
     _KeyGroupFun,
     _Fun,
-    Acc
+    Acc,
+    _Depth
 ) ->
     {ok, Acc, GroupedRedsAcc, GroupedKVsAcc, GroupedKey};
 reduce_stream_kv_node2(
@@ -855,7 +985,8 @@ reduce_stream_kv_node2(
     GroupedRedsAcc,
     KeyGroupFun,
     Fun,
-    Acc
+    Acc,
+    Depth
 ) ->
     case GroupedKey of
         undefined ->
@@ -867,7 +998,8 @@ reduce_stream_kv_node2(
                 [],
                 KeyGroupFun,
                 Fun,
-                Acc
+                Acc,
+                Depth
             );
         _ ->
             case KeyGroupFun(GroupedKey, Key) of
@@ -880,7 +1012,8 @@ reduce_stream_kv_node2(
                         GroupedRedsAcc,
                         KeyGroupFun,
                         Fun,
-                        Acc
+                        Acc,
+                        Depth
                     );
                 false ->
                     case Fun(GroupedKey, {GroupedKVsAcc, GroupedRedsAcc}, Acc) of
@@ -893,7 +1026,8 @@ reduce_stream_kv_node2(
                                 [],
                                 KeyGroupFun,
                                 Fun,
-                                Acc2
+                                Acc2,
+                                Depth
                             );
                         {stop, Acc2} ->
                             throw({stop, Acc2})
@@ -912,7 +1046,8 @@ reduce_stream_kp_node(
     GroupedRedsAcc,
     KeyGroupFun,
     Fun,
-    Acc
+    Acc,
+    Depth
 ) ->
     Nodes =
         case KeyStart of
@@ -955,7 +1090,8 @@ reduce_stream_kp_node(
         GroupedRedsAcc,
         KeyGroupFun,
         Fun,
-        Acc
+        Acc,
+        Depth
     ).
 
 reduce_stream_kp_node2(
@@ -969,7 +1105,8 @@ reduce_stream_kp_node2(
     [],
     KeyGroupFun,
     Fun,
-    Acc
+    Acc,
+    Depth
 ) ->
     {ok, Acc2, GroupedRedsAcc2, GroupedKVsAcc2, GroupedKey2} =
         reduce_stream_node(
@@ -983,7 +1120,8 @@ reduce_stream_kp_node2(
             [],
             KeyGroupFun,
             Fun,
-            Acc
+            Acc,
+            Depth
         ),
     reduce_stream_kp_node2(
         Bt,
@@ -996,7 +1134,8 @@ reduce_stream_kp_node2(
         GroupedRedsAcc2,
         KeyGroupFun,
         Fun,
-        Acc2
+        Acc2,
+        Depth
     );
 reduce_stream_kp_node2(
     Bt,
@@ -1009,7 +1148,8 @@ reduce_stream_kp_node2(
     GroupedRedsAcc,
     KeyGroupFun,
     Fun,
-    Acc
+    Acc,
+    Depth
 ) ->
     {Grouped0, Ungrouped0} = lists:splitwith(
         fun({Key, _}) ->
@@ -1040,7 +1180,8 @@ reduce_stream_kp_node2(
                     GroupedReds ++ GroupedRedsAcc,
                     KeyGroupFun,
                     Fun,
-                    Acc
+                    Acc,
+                    Depth
                 ),
             reduce_stream_kp_node2(
                 Bt,
@@ -1053,7 +1194,8 @@ reduce_stream_kp_node2(
                 GroupedRedsAcc2,
                 KeyGroupFun,
                 Fun,
-                Acc2
+                Acc2,
+                Depth
             );
         [] ->
             {ok, Acc, GroupedReds ++ GroupedRedsAcc, GroupedKVsAcc, GroupedKey}
@@ -1064,40 +1206,46 @@ adjust_dir(fwd, List) ->
 adjust_dir(rev, List) ->
     lists:reverse(List).
 
-stream_node(Bt, Reds, Node, StartKey, InRange, Dir, Fun, Acc) ->
+stream_node(Bt, Reds, Node, StartKey, InRange, Dir, Fun, Acc, Depth0) ->
+    Depth = Depth0 + 1,
     Pointer = element(1, Node),
-    {NodeType, NodeList} = get_node(Bt, Pointer),
+    {NodeType, NodeList} = get_node(Bt, Pointer, Depth),
     case NodeType of
         kp_node ->
-            stream_kp_node(Bt, Reds, adjust_dir(Dir, NodeList), StartKey, InRange, Dir, Fun, Acc);
+            stream_kp_node(
+                Bt, Reds, adjust_dir(Dir, NodeList), StartKey, InRange, Dir, Fun, Acc, Depth
+            );
         kv_node ->
-            stream_kv_node(Bt, Reds, adjust_dir(Dir, NodeList), StartKey, InRange, Dir, Fun, Acc)
+            stream_kv_node(
+                Bt, Reds, adjust_dir(Dir, NodeList), StartKey, InRange, Dir, Fun, Acc, Depth
+            )
     end.
 
-stream_node(Bt, Reds, Node, InRange, Dir, Fun, Acc) ->
+stream_node(Bt, Reds, Node, InRange, Dir, Fun, Acc, Depth0) ->
+    Depth = Depth0 + 1,
     Pointer = element(1, Node),
-    {NodeType, NodeList} = get_node(Bt, Pointer),
+    {NodeType, NodeList} = get_node(Bt, Pointer, Depth),
     case NodeType of
         kp_node ->
-            stream_kp_node(Bt, Reds, adjust_dir(Dir, NodeList), InRange, Dir, Fun, Acc);
+            stream_kp_node(Bt, Reds, adjust_dir(Dir, NodeList), InRange, Dir, Fun, Acc, Depth);
         kv_node ->
-            stream_kv_node2(Bt, Reds, [], adjust_dir(Dir, NodeList), InRange, Dir, Fun, Acc)
+            stream_kv_node2(Bt, Reds, [], adjust_dir(Dir, NodeList), InRange, Dir, Fun, Acc, Depth)
     end.
 
-stream_kp_node(_Bt, _Reds, [], _InRange, _Dir, _Fun, Acc) ->
+stream_kp_node(_Bt, _Reds, [], _InRange, _Dir, _Fun, Acc, _Depth) ->
     {ok, Acc};
-stream_kp_node(Bt, Reds, [{Key, Node} | Rest], InRange, Dir, Fun, Acc) ->
+stream_kp_node(Bt, Reds, [{Key, Node} | Rest], InRange, Dir, Fun, Acc, Depth) ->
     Red = element(2, Node),
     case Fun(traverse, Key, Red, Acc) of
         {ok, Acc2} ->
-            case stream_node(Bt, Reds, Node, InRange, Dir, Fun, Acc2) of
+            case stream_node(Bt, Reds, Node, InRange, Dir, Fun, Acc2, Depth) of
                 {ok, Acc3} ->
-                    stream_kp_node(Bt, [Red | Reds], Rest, InRange, Dir, Fun, Acc3);
+                    stream_kp_node(Bt, [Red | Reds], Rest, InRange, Dir, Fun, Acc3, Depth);
                 {stop, LastReds, Acc3} ->
                     {stop, LastReds, Acc3}
             end;
         {skip, Acc2} ->
-            stream_kp_node(Bt, [Red | Reds], Rest, InRange, Dir, Fun, Acc2);
+            stream_kp_node(Bt, [Red | Reds], Rest, InRange, Dir, Fun, Acc2, Depth);
         {stop, Acc2} ->
             {stop, Reds, Acc2}
     end.
@@ -1112,7 +1260,7 @@ drop_nodes(Bt, Reds, StartKey, [{NodeKey, Node} | RestKPs]) ->
             {Reds, [{NodeKey, Node} | RestKPs]}
     end.
 
-stream_kp_node(Bt, Reds, KPs, StartKey, InRange, Dir, Fun, Acc) ->
+stream_kp_node(Bt, Reds, KPs, StartKey, InRange, Dir, Fun, Acc, Depth) ->
     {NewReds, NodesToStream} =
         case Dir of
             fwd ->
@@ -1135,16 +1283,16 @@ stream_kp_node(Bt, Reds, KPs, StartKey, InRange, Dir, Fun, Acc) ->
         [] ->
             {ok, Acc};
         [{_Key, Node} | Rest] ->
-            case stream_node(Bt, NewReds, Node, StartKey, InRange, Dir, Fun, Acc) of
+            case stream_node(Bt, NewReds, Node, StartKey, InRange, Dir, Fun, Acc, Depth) of
                 {ok, Acc2} ->
                     Red = element(2, Node),
-                    stream_kp_node(Bt, [Red | NewReds], Rest, InRange, Dir, Fun, Acc2);
+                    stream_kp_node(Bt, [Red | NewReds], Rest, InRange, Dir, Fun, Acc2, Depth);
                 {stop, LastReds, Acc2} ->
                     {stop, LastReds, Acc2}
             end
     end.
 
-stream_kv_node(Bt, Reds, KVs, StartKey, InRange, Dir, Fun, Acc) ->
+stream_kv_node(Bt, Reds, KVs, StartKey, InRange, Dir, Fun, Acc, Depth) ->
     DropFun =
         case Dir of
             fwd ->
@@ -1154,11 +1302,11 @@ stream_kv_node(Bt, Reds, KVs, StartKey, InRange, Dir, Fun, Acc) ->
         end,
     {LTKVs, GTEKVs} = lists:splitwith(DropFun, KVs),
     AssembleLTKVs = [assemble(Bt, K, V) || {K, V} <- LTKVs],
-    stream_kv_node2(Bt, Reds, AssembleLTKVs, GTEKVs, InRange, Dir, Fun, Acc).
+    stream_kv_node2(Bt, Reds, AssembleLTKVs, GTEKVs, InRange, Dir, Fun, Acc, Depth).
 
-stream_kv_node2(_Bt, _Reds, _PrevKVs, [], _InRange, _Dir, _Fun, Acc) ->
+stream_kv_node2(_Bt, _Reds, _PrevKVs, [], _InRange, _Dir, _Fun, Acc, _Depth) ->
     {ok, Acc};
-stream_kv_node2(Bt, Reds, PrevKVs, [{K, V} | RestKVs], InRange, Dir, Fun, Acc) ->
+stream_kv_node2(Bt, Reds, PrevKVs, [{K, V} | RestKVs], InRange, Dir, Fun, Acc, Depth) ->
     case InRange(K) of
         false ->
             {stop, {PrevKVs, Reds}, Acc};
@@ -1167,7 +1315,7 @@ stream_kv_node2(Bt, Reds, PrevKVs, [{K, V} | RestKVs], InRange, Dir, Fun, Acc) -
             case Fun(visit, AssembledKV, {PrevKVs, Reds}, Acc) of
                 {ok, Acc2} ->
                     stream_kv_node2(
-                        Bt, Reds, [AssembledKV | PrevKVs], RestKVs, InRange, Dir, Fun, Acc2
+                        Bt, Reds, [AssembledKV | PrevKVs], RestKVs, InRange, Dir, Fun, Acc2, Depth
                     );
                 {stop, Acc2} ->
                     {stop, {PrevKVs, Reds}, Acc2}
