@@ -329,7 +329,7 @@ split_host_port(HostAsString) ->
         N ->
             HostPart = string:substr(HostAsString, 1, N - 1),
             case
-                (catch erlang:list_to_integer(
+                (catch list_to_integer(
                     string:substr(
                         HostAsString,
                         N + 1,
