@@ -162,7 +162,7 @@ handle_call({get_proc, #client{} = Client}, From, State) ->
     {noreply, State};
 handle_call({ret_proc, #proc{} = Proc}, From, State) ->
     #proc{client = Ref, pid = Pid} = Proc,
-    erlang:demonitor(Ref, [flush]),
+    demonitor(Ref, [flush]),
     gen_server:reply(From, true),
     case ets:lookup(?PROCS, Pid) of
         [#proc{} = ProcInt] ->
@@ -615,7 +615,7 @@ make_proc(Pid, Lang, Mod) when is_binary(Lang) ->
     {ok, Proc}.
 
 assign_proc(Pid, #proc{client = undefined} = Proc0) when is_pid(Pid) ->
-    Proc = Proc0#proc{client = erlang:monitor(process, Pid)},
+    Proc = Proc0#proc{client = monitor(process, Pid)},
     % It's important to insert the proc here instead of doing an update_element
     % as we might have updated the db_key or ddoc_keys in teach_ddoc/4
     ets:insert(?PROCS, Proc),
@@ -730,13 +730,25 @@ remove_waiting_client(#client{wait_key = Key}) ->
     ets:delete(?WAITERS, Key).
 
 get_proc_config() ->
-    Limit = config:get_boolean("query_server_config", "reduce_limit", true),
-    Timeout = get_os_process_timeout(),
     {[
-        {<<"reduce_limit">>, Limit},
-        {<<"timeout">>, Timeout}
+        {<<"reduce_limit">>, get_reduce_limit()},
+        {<<"reduce_limit_threshold">>, couch_query_servers:reduce_limit_threshold()},
+        {<<"reduce_limit_ratio">>, couch_query_servers:reduce_limit_ratio()},
+        {<<"timeout">>, get_os_process_timeout()}
     ]}.
 
+% Reduce limit is a tri-state value of true, false or log. The default value if
+% is true. That's also the value if anything other than those 3 values are
+% specified.
+%
+get_reduce_limit() ->
+    case config:get("query_server_config", "reduce_limit", "true") of
+        "false" -> false;
+        "log" -> log;
+        "true" -> true;
+        Other when is_list(Other) -> true
+    end.
+
 get_hard_limit() ->
     config:get_integer("query_server_config", "os_process_limit", 100).
 
