@@ -19,6 +19,7 @@
 -export([filter_view/4]).
 -export([finalize/2]).
 -export([rewrite/3]).
+-export([reduce_limit_threshold/0, reduce_limit_ratio/0]).
 
 -export([with_ddoc_proc/3, proc_prompt/2, ddoc_prompt/4, ddoc_proc_prompt/3, json_doc/1]).
 
@@ -278,7 +279,7 @@ sum_arrays(Else, _) ->
     throw_sum_error(Else).
 
 check_sum_overflow(InSize, OutSize, Sum) ->
-    Overflowed = OutSize > 4906 andalso OutSize * 2 > InSize,
+    Overflowed = OutSize > reduce_limit_threshold() andalso OutSize * reduce_limit_ratio() > InSize,
     case config:get("query_server_config", "reduce_limit", "true") of
         "true" when Overflowed ->
             Msg = log_sum_overflow(InSize, OutSize),
@@ -302,6 +303,12 @@ log_sum_overflow(InSize, OutSize) ->
     couch_log:error(Msg, []),
     Msg.
 
+reduce_limit_threshold() ->
+    config:get_integer("query_server_config", "reduce_limit_threshold", 5000).
+
+reduce_limit_ratio() ->
+    config:get_float("query_server_config", "reduce_limit_ratio", 2.0).
+
 builtin_stats(_, []) ->
     {0, 0, 0, 0, 0};
 builtin_stats(_, [[_, First] | Rest]) ->
@@ -327,8 +334,8 @@ stat_values(Value, Acc) when is_tuple(Value), is_tuple(Acc) ->
     {
         Sum0 + Sum1,
         Cnt0 + Cnt1,
-        erlang:min(Min0, Min1),
-        erlang:max(Max0, Max1),
+        min(Min0, Min1),
+        max(Max0, Max1),
         Sqr0 + Sqr1
     };
 stat_values(Else, _Acc) ->
