@@ -16,14 +16,13 @@
 
 -define(TIMEOUT, 120).
 
-
-
-create_delete_db_test_()->
+create_delete_db_test_() ->
     {
         "Database create/delete tests",
         {
             setup,
-            fun test_util:start_couch/0, fun test_util:stop_couch/1,
+            fun test_util:start_couch/0,
+            fun test_util:stop_couch/1,
             {
                 foreach,
                 fun() -> ?tempdb() end,
@@ -35,12 +34,13 @@ create_delete_db_test_()->
         }
     }.
 
-create_delete_multiple_dbs_test_()->
+create_delete_multiple_dbs_test_() ->
     {
         "Multiple database create/delete tests",
         {
             setup,
-            fun test_util:start_couch/0, fun test_util:stop_couch/1,
+            fun test_util:start_couch/0,
+            fun test_util:stop_couch/1,
             {
                 foreach,
                 fun() -> [?tempdb() || _ <- lists:seq(1, 6)] end,
@@ -57,7 +57,8 @@ create_delete_database_continuously_test_() ->
         "Continious database create/delete tests",
         {
             setup,
-            fun test_util:start_couch/0, fun test_util:stop_couch/1,
+            fun test_util:start_couch/0,
+            fun test_util:stop_couch/1,
             {
                 foreachx,
                 fun(_) -> ?tempdb() end,
@@ -69,12 +70,13 @@ create_delete_database_continuously_test_() ->
         }
     }.
 
-open_db_test_()->
+open_db_test_() ->
     {
         "Database open tests",
         {
             setup,
-            fun test_util:start_couch/0, fun test_util:stop_couch/1,
+            fun test_util:start_couch/0,
+            fun test_util:stop_couch/1,
             {
                 foreach,
                 fun() -> ?tempdb() end,
@@ -87,7 +89,6 @@ open_db_test_()->
         }
     }.
 
-
 should_create_db(DbName) ->
     ?_test(begin
         {ok, Before} = couch_server:all_databases(),
@@ -109,10 +110,12 @@ should_delete_db(DbName) ->
 
 should_create_multiple_dbs(DbNames) ->
     ?_test(begin
-        [gen_server:call(couch_server:couch_server(N), {set_max_dbs_open, 3}) ||
-            N <- lists:seq(1, couch_server:num_servers())],
+        [
+            gen_server:call(couch_server:couch_server(N), {set_max_dbs_open, 3})
+         || N <- lists:seq(1, couch_server:num_servers())
+        ],
         {ok, Before} = couch_server:all_databases(),
-        [?assertNot(lists:member(DbName, Before))  || DbName <- DbNames],
+        [?assertNot(lists:member(DbName, Before)) || DbName <- DbNames],
         [?assert(create_db(DbName)) || DbName <- DbNames],
         {ok, After} = couch_server:all_databases(),
         [?assert(lists:member(DbName, After)) || DbName <- DbNames]
@@ -122,21 +125,27 @@ should_delete_multiple_dbs(DbNames) ->
     ?_test(begin
         [?assert(create_db(DbName)) || DbName <- DbNames],
         {ok, Before} = couch_server:all_databases(),
-        [?assert(lists:member(DbName, Before))  || DbName <- DbNames],
+        [?assert(lists:member(DbName, Before)) || DbName <- DbNames],
         [?assert(delete_db(DbName)) || DbName <- DbNames],
         {ok, After} = couch_server:all_databases(),
         [?assertNot(lists:member(DbName, After)) || DbName <- DbNames]
     end).
 
 should_create_delete_database_continuously(Times, DbName) ->
-    {lists:flatten(io_lib:format("~b times", [Times])),
-    {timeout, ?TIMEOUT, ?_test(begin
-        ?assert(create_db(DbName)),
-        lists:foreach(fun(_) ->
-            ?assert(delete_db(DbName)),
-            ?assert(create_db(DbName))
-        end, lists:seq(1, Times))
-    end)}}.
+    {
+        lists:flatten(io_lib:format("~b times", [Times])),
+        {timeout, ?TIMEOUT,
+            ?_test(begin
+                ?assert(create_db(DbName)),
+                lists:foreach(
+                    fun(_) ->
+                        ?assert(delete_db(DbName)),
+                        ?assert(create_db(DbName))
+                    end,
+                    lists:seq(1, Times)
+                )
+            end)}
+    }.
 
 should_create_db_if_missing(DbName) ->
     ?_test(begin
@@ -165,8 +174,10 @@ locking_should_work(DbName) ->
         ?assertEqual({error, {locked, <<"x">>}}, couch_db:create(DbName, [])),
         ?assertEqual(ok, couch_server:unlock(DbName)),
         {ok, Db} = couch_db:create(DbName, []),
-        ?assertEqual({error, already_opened},
-            couch_server:lock(DbName, <<>>)),
+        ?assertEqual(
+            {error, already_opened},
+            couch_server:lock(DbName, <<>>)
+        ),
 
         ok = couch_db:close(Db),
         catch exit(couch_db:get_pid(Db), kill),
@@ -175,11 +186,13 @@ locking_should_work(DbName) ->
                 [] -> ok;
                 [_ | _] -> wait
             end
-         end),
+        end),
 
         ?assertEqual(ok, couch_server:lock(DbName, <<"y">>)),
-        ?assertEqual({error, {locked, <<"y">>}},
-            couch_db:open(DbName, [])),
+        ?assertEqual(
+            {error, {locked, <<"y">>}},
+            couch_db:open(DbName, [])
+        ),
 
         couch_server:unlock(DbName),
         {ok, Db1} = couch_db:open(DbName, [{create_if_missing, true}]),
