@@ -288,7 +288,7 @@ wait_compaction(DbName, Line) ->
     end,
     case test_util:wait(WaitFun, 10000) of
         timeout ->
-            erlang:error(
+            error(
                 {assertion_failed, [
                     {module, ?MODULE},
                     {line, Line},
