@@ -28,7 +28,7 @@ init([]) ->
     {ok,
         {
             {one_for_one, 5, 10}, [
-                ?CHILD(couch_stats_aggregator, worker),
+                ?CHILD(couch_stats_server, worker),
                 ?CHILD(couch_stats_process_tracker, worker)
             ]
         }}.
