@@ -12,7 +12,6 @@
 
 -module(custodian_db_checker).
 -behaviour(gen_server).
--vsn(1).
 
 -export([start_link/0]).
 
@@ -21,8 +20,7 @@
     terminate/2,
     handle_call/3,
     handle_cast/2,
-    handle_info/2,
-    code_change/3
+    handle_info/2
 ]).
 
 -export([
@@ -65,9 +63,6 @@ handle_info({'EXIT', Pid, Reason}, #st{checker = Pid} = St) ->
 handle_info(Msg, St) ->
     {stop, {invalid_info, Msg}, St}.
 
-code_change(_OldVsn, St, _Extra) ->
-    {ok, St}.
-
 restart_checker(#st{checker = undefined} = St) ->
     Pid = spawn_link(fun ?MODULE:check_dbs/0),
     St#st{checker = Pid};
