@@ -12,17 +12,15 @@
 
 -module(custodian_monitor).
 
-
 % N.B. that callback return values are ignored
 
 -callback send_missing_db_alert(DbName :: binary()) ->
     Ignored :: any().
 
-
 -callback clear_missing_dbs_alert() ->
     Ignored :: any().
 
-
 -callback send_event(
-    Name :: string(), Count :: non_neg_integer(), Description :: string()) ->
+    Name :: string(), Count :: non_neg_integer(), Description :: string()
+) ->
     Ignored :: any().
