@@ -14,9 +14,7 @@
 
 -module(dreyfus_fabric_info).
 
--include("dreyfus.hrl").
 -include_lib("mem3/include/mem3.hrl").
--include_lib("couch/include/couch_db.hrl").
 
 -export([go/4]).
 
