@@ -1,4 +1,4 @@
-%% Copyright (c) Facebook, Inc. and its affiliates.
+%% Copyright (c) Meta Platforms, Inc. and its affiliates.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -107,8 +107,26 @@ with_parsed(Name, Config) ->
             erlang:halt(127)
     end.
 
+-spec set_difference([file:name_all()], [file:name_all()]) -> [file:name_all()].
 set_difference(Files, Excludes) ->
-    sets:to_list(sets:subtract(sets:from_list(Files), sets:from_list(Excludes))).
+    {ok, Cwd} = file:get_cwd(),
+    AbsoluteFiles = maps:from_list([{resolve_path(Cwd, F), F} || F <- Files]),
+    AbsoluteExcludes = [resolve_path(Cwd, E) || E <- Excludes],
+    maps:values(maps:without(AbsoluteExcludes, AbsoluteFiles)).
+
+resolve_path(Dir, Filename) ->
+    resolve_path2(filename:absname(Filename, Dir)).
+
+resolve_path2(AbsPath) ->
+    [Volume | Components] = filename:split(AbsPath),
+    filename:join(resolve_path2(Components, [Volume])).
+
+resolve_path2([".." | T1], [Volume]) -> resolve_path2(T1, [Volume]);
+resolve_path2([<<"..">> | T1], [Volume]) -> resolve_path2(T1, [Volume]);
+resolve_path2([".." | T1], [_H2 | T2]) -> resolve_path2(T1, T2);
+resolve_path2([<<"..">> | T1], [_H2 | T2]) -> resolve_path2(T1, T2);
+resolve_path2([H1 | T1], Components) -> resolve_path2(T1, [H1 | Components]);
+resolve_path2([], Components) -> lists:reverse(Components).
 
 %% needed because of getopt
 -dialyzer({nowarn_function, [unprotected_with_config/2]}).
