@@ -198,7 +198,7 @@ spawn_worker_cleaner(Coordinator, Workers, ClientReq) when
     case get(?WORKER_CLEANER) of
         undefined ->
             Pid = spawn(fun() ->
-                erlang:monitor(process, Coordinator),
+                monitor(process, Coordinator),
                 NodeRefSet = couch_util:set_from_list(shards_to_node_refs(Workers)),
                 cleaner_loop(Coordinator, NodeRefSet, ClientReq)
             end),
@@ -269,7 +269,7 @@ should_clean_workers(_) ->
         end
     end),
     Cleaner = spawn_worker_cleaner(Coord, Workers, undefined),
-    Ref = erlang:monitor(process, Cleaner),
+    Ref = monitor(process, Cleaner),
     Coord ! die,
     receive
         {'DOWN', Ref, _, Cleaner, _} -> ok
@@ -289,7 +289,7 @@ does_not_fire_if_cleanup_called(_) ->
         end
     end),
     Cleaner = spawn_worker_cleaner(Coord, Workers, undefined),
-    Ref = erlang:monitor(process, Cleaner),
+    Ref = monitor(process, Cleaner),
     cleanup(Workers),
     Coord ! die,
     receive
@@ -312,7 +312,7 @@ should_clean_additional_worker_too(_) ->
     end),
     Cleaner = spawn_worker_cleaner(Coord, Workers, undefined),
     add_worker_to_cleaner(Coord, #shard{node = 'n2', ref = make_ref()}),
-    Ref = erlang:monitor(process, Cleaner),
+    Ref = monitor(process, Cleaner),
     Coord ! die,
     receive
         {'DOWN', Ref, _, Cleaner, _} -> ok
@@ -337,7 +337,7 @@ coordinator_is_killed_if_client_disconnects(_) ->
     % Close the socket and then expect coordinator to be killed
     ok = gen_tcp:close(Sock),
     Cleaner = spawn_worker_cleaner(Coord, Workers, ClientReq),
-    CleanerRef = erlang:monitor(process, Cleaner),
+    CleanerRef = monitor(process, Cleaner),
     % Assert the correct behavior on the support platforms (all except Windows so far)
     case os:type() of
         {unix, Type} when
@@ -378,7 +378,7 @@ coordinator_is_not_killed_if_client_is_connected(_) ->
     {ok, Sock} = gen_tcp:listen(0, [{active, false}]),
     ClientReq = mochiweb_request:new(Sock, 'GET', "/foo", {1, 1}, Headers),
     Cleaner = spawn_worker_cleaner(Coord, Workers, ClientReq),
-    CleanerRef = erlang:monitor(process, Cleaner),
+    CleanerRef = monitor(process, Cleaner),
     % Coordinator should stay up
     receive
         {'DOWN', CoordRef, _, Coord, _} ->
@@ -430,7 +430,7 @@ submit_jobs_sets_up_cleaner(_) ->
     meck:wait(2, rexi, cast_ref, '_', 1000),
     % If we kill the coordinator, the cleaner should kill the workers
     meck:reset(rexi),
-    CleanupMon = erlang:monitor(process, Cleaner),
+    CleanupMon = monitor(process, Cleaner),
     exit(Coord, kill),
     receive
         {'DOWN', CoordRef, _, _, WorkerReason} ->
