@@ -144,7 +144,7 @@ go(DbName, _Options, Workers, QueryArgs, Callback, Acc0) ->
             fun handle_message/3,
             State,
             fabric_util:view_timeout(QueryArgs),
-            5000
+            fabric_util:timeout("all_docs_view_permsg", "5000")
         )
     of
         {ok, NewState} ->
@@ -239,7 +239,7 @@ handle_message({meta, Meta0}, {Worker, From}, State) ->
             FinalOffset =
                 case Offset of
                     null -> null;
-                    _ -> erlang:min(Total, Offset + State#collector.skip)
+                    _ -> min(Total, Offset + State#collector.skip)
                 end,
             Meta =
                 [{total, Total}, {offset, FinalOffset}] ++
@@ -373,7 +373,7 @@ cancel_read_pids(Pids) ->
     case queue:out(Pids) of
         {{value, {Pid, Ref}}, RestPids} ->
             exit(Pid, kill),
-            erlang:demonitor(Ref, [flush]),
+            demonitor(Ref, [flush]),
             cancel_read_pids(RestPids);
         {empty, _} ->
             ok
