@@ -388,7 +388,7 @@ pack_seqs(Workers) ->
     SeqList = [{N, R, S} || {#shard{node = N, range = R}, S} <- Workers],
     SeqSum = lists:sum([fake_packed_seq(S) || {_, _, S} <- SeqList]),
     Opaque = couch_util:encodeBase64Url(?term_to_bin(SeqList, [compressed])),
-    ?l2b([integer_to_list(SeqSum), $-, Opaque]).
+    <<(integer_to_binary(SeqSum))/binary, $-, Opaque/binary>>.
 
 % Generate the sequence number used to build the emitted N-... prefix.
 %
@@ -536,7 +536,7 @@ get_old_seq(#shard{range = R} = Shard, SinceSeqs) ->
 
 get_db_uuid_shards(DbName) ->
     % Need to use an isolated process as we are performing a fabric call from
-    % another fabric call and there is a good chance we'd polute the mailbox
+    % another fabric call and there is a good chance we'd pollute the mailbox
     % with returned messages
     Timeout = fabric_util:request_timeout(),
     IsolatedFun = fun() -> fabric:db_uuids(DbName) end,
