@@ -19,16 +19,16 @@ describe('Badges', () => {
       <ReactComponents.BadgeList elements={['foo', 'bar']} removeBadge={() => {}} />
     );
 
-    expect(el.find('.component-badge').length).toBe(2);
+    expect(el.find('.badge').length).toBe(2);
   });
 
   it('supports custom label formatters', () => {
     const el = mount(
-      <ReactComponents.BadgeList elements={['foo', 'bar']} removeBadge={() => {}} getLabel={(el) => { return el + 'foo'; }} />
+      <ReactComponents.BadgeList elements={['foo', 'bar']} removeBadge={() => {}} showClose={true} getLabel={(el) => { return el + 'foo'; }} />
     );
 
-    expect(el.find('.component-badge').first().text()).toBe('foofoo×');
-    expect(el.find('.component-badge').last().text()).toBe('barfoo×');
+    expect(el.find('.badge').first().text()).toBe('foofoo×');
+    expect(el.find('.badge').last().text()).toBe('barfoo×');
   });
 
 });
