@@ -15,7 +15,6 @@ import ReactDOM from "react-dom";
 import ReactSelect from "react-select";
 
 export class ThrottledReactSelectAsync extends React.Component {
-
   constructor(props) {
     super(props);
     this.lastCall = undefined;
@@ -38,13 +37,14 @@ export class ThrottledReactSelectAsync extends React.Component {
   render() {
     // wrapThrottler() must be called here to ensure a new
     // function is created when props.loadOptions is updated
-    const throttledLoadOptions = this.wrapThrottler(this.props.loadOptions).bind(this);
+    const throttledLoadOptions = this.wrapThrottler(
+      this.props.loadOptions
+    ).bind(this);
     const newProps = {
       ...this.props,
-      loadOptions: throttledLoadOptions
+      loadOptions: throttledLoadOptions,
+      onBlurResetsInput: false
     };
-    return (
-      <ReactSelect.Async {...newProps} />
-    );
+    return <ReactSelect.Async {...newProps} />;
   }
 }
