@@ -17,6 +17,7 @@ import { v4 as uuidv4 } from 'uuid';
 import FauxtonAPI from '../../../../../core/api';
 import Components from '../../../../components/react-components';
 import Constants from '../../../constants';
+import Form from 'react-bootstrap/Form';
 
 const { Copy } = Components;
 
@@ -64,11 +65,12 @@ export default class TableRow extends React.Component {
   maybeGetCheckboxCell (el, i) {
     return (
       <td className="tableview-checkbox-cell" key={"tableview-checkbox-cell-" + i}>
-        {el.isDeletable ? <input
+        {el.isDeletable ? <Form.Check
           id={"checkbox-" + this.props.docIdentifier}
           checked={this.props.isSelected}
           type="checkbox"
-          onChange={this.onChange.bind(this)} /> : null}
+          onChange={this.onChange.bind(this)}
+        /> : null}
       </td>
     );
   }
@@ -78,7 +80,7 @@ export default class TableRow extends React.Component {
     let attachmentIndicator = null;
     let textAttachments = null;
 
-    const conflictCount = Object.keys(el._conflicts || {}).length;
+    let conflictCount = Object.keys(el._conflicts || {}).length;
     let conflictIndicator = null;
     let textConflicts = null;
 
@@ -97,8 +99,7 @@ export default class TableRow extends React.Component {
       conflictIndicator = (
         <div className="tableview-conflict" data-conflicts-indicator style={{display: 'inline'}} title={textConflicts}>
           <i
-            style={{fontSize: '17px'}}
-            className="icon icon-code-fork"></i>{conflictCount}
+            className="fonticon-code-branch"></i>{conflictCount}
         </div>
       );
     }
