@@ -26,9 +26,9 @@ module.exports = {
       .url(baseUrl + '/#/database/' + newDatabaseName + '/_all_docs')
       .waitForElementNotPresent('.loading-lines', waitTime, false)
       .clickWhenVisible('.control-toggle-queryoptions')
-      .clickWhenVisible('#betweenKeys', waitTime, false)
-      .setValue('#startkey', '"document_2"')
-      .clickWhenVisible('.query-options .btn-secondary')
+      .clickWhenVisible('label[for="betweenKeys"]', waitTime, false)
+      .setValue('input#startkey', '"document_2"')
+      .clickWhenVisible('#query-options-tray #button-options .btn-cf-primary')
       .waitForElementNotPresent('.loading-lines', waitTime, false)
       .clickWhenVisible('.fonticon-json')
       .waitForElementNotPresent('.loading-lines', waitTime, false)
