@@ -1,3 +1,4 @@
+
 // Licensed under the Apache License, Version 2.0 (the "License"); you may not
 // use this file except in compliance with the License. You may obtain a copy of
 // the License at
@@ -27,15 +28,15 @@ module.exports = {
       .clickWhenVisible('.fonticon-json')
       .waitForElementNotPresent('.loading-lines', waitTime, false)
       .clickWhenVisible('.control-toggle-queryoptions')
-      .clickWhenVisible('#betweenKeys', waitTime, false)
-      .setValue('#startkey', '"document_2"')
-      .clickWhenVisible('.query-options .btn-secondary')
+      .clickWhenVisible('label[for="betweenKeys"]', waitTime, false)
+      .setValue('input#startkey', '"document_2"')
+      .clickWhenVisible('#query-options-tray #button-options .btn-cf-primary')
       .waitForElementNotPresent('.loading-lines', waitTime, false)
       .waitForElementNotPresent('#doc-list [data-id="document_1"]', waitTime, false)
       .clickWhenVisible('.control-toggle-queryoptions')
-      .clickWhenVisible('.query-options .btn-cancelDark')
+      .clickWhenVisible('#query-options-tray #button-options .btn-cf-cancel')
 
-      .waitForElementNotPresent('.query-options .js-view-query-update', waitTime, false)
+      .waitForElementNotPresent('#query-options_js-view-query-update', waitTime, false)
 
       .end();
   }
