@@ -17,7 +17,7 @@ module.exports = {
   'Shows how many conflicts have appeared': function (client) {
     const waitTime = client.globals.maxWaitTime;
     const newDatabaseName = client.globals.testDatabaseName;
-    const baseUrl = client.globals.test_settings.launch_url;
+    const baseUrl = client.options.launch_url;
 
     client
       .populateDatabaseWithConflicts(newDatabaseName)
