@@ -17,9 +17,6 @@ export default {
   CLEAR_SINGLE_NOTIFICATION: 'CLEAR_SINGLE_NOTIFICATION',
   CLEAR_ALL_NOTIFICATIONS: 'CLEAR_ALL_NOTIFICATIONS',
   SELECT_NOTIFICATION_FILTER: 'SELECT_NOTIFICATION_FILTER',
-  START_HIDING_NOTIFICATION: 'START_HIDING_NOTIFICATION',
-  HIDE_NOTIFICATION: 'HIDE_NOTIFICATION',
-  HIDE_ALL_NOTIFICATIONS: 'HIDE_ALL_NOTIFICATIONS',
   SHOW_PERMANENT_NOTIFICATION: 'SHOW_PERMANENT_NOTIFICATION',
   HIDE_PERMANENT_NOTIFICATION: 'HIDE_PERMANENT_NOTIFICATION'
 };
