@@ -10,8 +10,9 @@
 // License for the specific language governing permissions and limitations under
 // the License.
 
-import React from 'react';
 import PropTypes from 'prop-types';
+import React from 'react';
+import { Form } from 'react-bootstrap';
 
 
 export default class NodeCountSetting extends React.Component {
@@ -22,14 +23,14 @@ export default class NodeCountSetting extends React.Component {
 
   render() {
     return (
-      <div className="setup-node-count">
-        <p>Number of nodes to be added to the cluster (including this one)</p>
-        <input
-          className="setup-input-nodecount"
-          value={this.props.nodeCount}
-          onChange={this.handleNodeCountChange}
-          placeholder="Value of cluster n"
-          type="text"/>
+      <div className="row">
+        <div className="col-12 col-md-5 col-xl-4 mb-3">
+          <label>Number of nodes to be added to the cluster (including this one)</label>
+          <Form.Control type="text"
+            value={this.props.nodeCount}
+            onChange={this.handleNodeCountChange}
+            placeholder="Value of cluster n" />
+        </div>
       </div>
     );
   }
