@@ -20,12 +20,18 @@
 -export([
     encode/3,
     decode/3,
+    decode/4,
+    decode_b64url_json/1,
+    decode_passthrough/1,
     valid_algorithms/0,
     verification_algorithm/1
 ]).
 
+-include_lib("public_key/include/public_key.hrl").
+
 -define(ALGS, [
-    {<<"RS256">>, {public_key, sha256}}, % RSA PKCS#1 signature with SHA-256
+    % RSA PKCS#1 signature with SHA-256
+    {<<"RS256">>, {public_key, sha256}},
     {<<"RS384">>, {public_key, sha384}},
     {<<"RS512">>, {public_key, sha512}},
     {<<"ES256">>, {public_key, sha256}},
@@ -33,7 +39,8 @@
     {<<"ES512">>, {public_key, sha512}},
     {<<"HS256">>, {hmac, sha256}},
     {<<"HS384">>, {hmac, sha384}},
-    {<<"HS512">>, {hmac, sha512}}]).
+    {<<"HS512">>, {hmac, sha512}}
+]).
 
 -define(CHECKS, [
     alg,
@@ -43,8 +50,8 @@
     kid,
     nbf,
     sig,
-    typ]).
-
+    typ
+]).
 
 % @doc encode
 % Encode the JSON Header and Claims using Key and Alg obtained from Header
@@ -52,21 +59,29 @@
     {ok, binary()} | no_return().
 encode(Header = {HeaderProps}, Claims, Key) ->
     try
-        Alg = case prop(<<"alg">>, HeaderProps) of
-            undefined ->
-                throw({bad_request, <<"Missing alg header parameter">>});
-            Val ->
-                Val
-        end,
+        Alg =
+            case prop(<<"alg">>, HeaderProps) of
+                undefined ->
+                    throw({bad_request, <<"Missing alg header parameter">>});
+                Val ->
+                    Val
+            end,
         EncodedHeader = b64url:encode(jiffy:encode(Header)),
         EncodedClaims = b64url:encode(jiffy:encode(Claims)),
         Message = <<EncodedHeader/binary, $., EncodedClaims/binary>>,
-        SignatureOrMac = case verification_algorithm(Alg) of
-            {public_key, Algorithm} ->
-                public_key:sign(Message, Algorithm, Key);
-            {hmac, Algorithm} ->
-                hmac(Algorithm, Key, Message)
-        end,
+        SignatureOrMac =
+            case verification_algorithm(Alg) of
+                {public_key, Algorithm} ->
+                    Signature = public_key:sign(Message, Algorithm, Key),
+                    case Alg of
+                        <<"ES", _/binary>> ->
+                            der_to_jose(Alg, Signature);
+                        _ ->
+                            Signature
+                    end;
+                {hmac, Algorithm} ->
+                    hmac(Algorithm, Key, Message)
+            end,
         EncodedSignatureOrMac = b64url:encode(SignatureOrMac),
         {ok, <<Message/binary, $., EncodedSignatureOrMac/binary>>}
     catch
@@ -74,30 +89,31 @@ encode(Header = {HeaderProps}, Claims, Key) ->
             {error, Error}
     end.
 
-
 % @doc decode
 % Decodes the supplied encoded token, checking
-% for the attributes defined in Checks and calling
+% for the attributes defined in Checks, calling
 % the key store function to retrieve the key needed
-% to verify the signature
+% to verify the signature, and decoding the Payload
+% with the Decoder, defaulting to decode_b64url_json/1.
 decode(EncodedToken, Checks, KS) ->
+    decode(EncodedToken, Checks, KS, fun decode_b64url_json/1).
+
+decode(EncodedToken, Checks, KS, Decoder) ->
     try
         [Header, Payload, Signature] = split(EncodedToken),
         validate(Header, Payload, Signature, Checks, KS),
-        {ok, decode_b64url_json(Payload)}
+        {ok, Decoder(Payload)}
     catch
         throw:Error ->
             {error, Error}
     end.
 
-
 % @doc valid_algorithms
 % Return a list of supported algorithms
 -spec valid_algorithms() -> [binary()].
 valid_algorithms() ->
     proplists:get_keys(?ALGS).
 
-
 % @doc verification_algorithm
 % Return {VerificationMethod, Algorithm} tuple for the specified Alg
 -spec verification_algorithm(binary()) ->
@@ -110,7 +126,6 @@ verification_algorithm(Alg) ->
             throw({bad_request, <<"Invalid alg header parameter">>})
     end.
 
-
 validate(Header0, Payload0, Signature, Checks, KS) ->
     validate_checks(Checks),
     Header1 = props(decode_b64url_json(Header0)),
@@ -123,7 +138,6 @@ validate(Header0, Payload0, Signature, Checks, KS) ->
     Key = key(Header1, Checks, KS),
     verify(Alg, Header0, Payload0, Signature, Key).
 
-
 validate_checks(Checks) when is_list(Checks) ->
     case {lists:usort(Checks), lists:sort(Checks)} of
         {L, L} ->
@@ -139,22 +153,17 @@ validate_checks(Checks) when is_list(Checks) ->
             error({unknown_checks, UnknownChecks})
     end.
 
-
 valid_check(Check) when is_atom(Check) ->
     lists:member(Check, ?CHECKS);
-
 valid_check({Check, _}) when is_atom(Check) ->
     lists:member(Check, ?CHECKS);
-
 valid_check(_) ->
     false.
 
-
 validate_header(Props, Checks) ->
     validate_typ(Props, Checks),
     validate_alg(Props, Checks).
 
-
 validate_typ(Props, Checks) ->
     Required = prop(typ, Checks),
     TYP = prop(<<"typ">>, Props),
@@ -169,7 +178,6 @@ validate_typ(Props, Checks) ->
             throw({bad_request, <<"Invalid typ header parameter">>})
     end.
 
-
 validate_alg(Props, Checks) ->
     Required = prop(alg, Checks),
     Alg = prop(<<"alg">>, Props),
@@ -187,7 +195,6 @@ validate_alg(Props, Checks) ->
             end
     end.
 
-
 %% Only validate required checks.
 validate_payload(Props, Checks) ->
     validate_iss(Props, Checks),
@@ -195,13 +202,13 @@ validate_payload(Props, Checks) ->
     validate_nbf(Props, Checks),
     validate_exp(Props, Checks).
 
-
 validate_iss(Props, Checks) ->
     ExpectedISS = prop(iss, Checks),
     ActualISS = prop(<<"iss">>, Props),
 
     case {ExpectedISS, ActualISS} of
-        {undefined, _} -> % ignore unrequired check
+        % ignore unrequired check
+        {undefined, _} ->
             ok;
         {ISS, undefined} when ISS /= undefined ->
             throw({bad_request, <<"Missing iss claim">>});
@@ -211,13 +218,13 @@ validate_iss(Props, Checks) ->
             throw({bad_request, <<"Invalid iss claim">>})
     end.
 
-
 validate_iat(Props, Checks) ->
     Required = prop(iat, Checks),
     IAT = prop(<<"iat">>, Props),
 
     case {Required, IAT} of
-        {undefined, _} -> % ignore unrequired check
+        % ignore unrequired check
+        {undefined, _} ->
             ok;
         {true, undefined} ->
             throw({bad_request, <<"Missing iat claim">>});
@@ -227,13 +234,13 @@ validate_iat(Props, Checks) ->
             throw({bad_request, <<"Invalid iat claim">>})
     end.
 
-
 validate_nbf(Props, Checks) ->
     Required = prop(nbf, Checks),
     NBF = prop(<<"nbf">>, Props),
 
     case {Required, NBF} of
-        {undefined, _} -> % ignore unrequired check
+        % ignore unrequired check
+        {undefined, _} ->
             ok;
         {true, undefined} ->
             throw({bad_request, <<"Missing nbf claim">>});
@@ -241,13 +248,13 @@ validate_nbf(Props, Checks) ->
             assert_past(<<"nbf">>, NBF)
     end.
 
-
 validate_exp(Props, Checks) ->
     Required = prop(exp, Checks),
     EXP = prop(<<"exp">>, Props),
 
     case {Required, EXP} of
-        {undefined, _} -> % ignore unrequired check
+        % ignore unrequired check
+        {undefined, _} ->
             ok;
         {true, undefined} ->
             throw({bad_request, <<"Missing exp claim">>});
@@ -255,7 +262,6 @@ validate_exp(Props, Checks) ->
             assert_future(<<"exp">>, EXP)
     end.
 
-
 key(Props, Checks, KS) ->
     Alg = prop(<<"alg">>, Props),
     Required = prop(kid, Checks),
@@ -267,19 +273,24 @@ key(Props, Checks, KS) ->
             KS(Alg, KID)
     end.
 
-
 verify(Alg, Header, Payload, SignatureOrMac0, Key) ->
     Message = <<Header/binary, $., Payload/binary>>,
     SignatureOrMac1 = b64url:decode(SignatureOrMac0),
+    SignatureOrMac2 =
+        case Alg of
+            <<"ES", _/binary>> ->
+                jose_to_der(SignatureOrMac1);
+            _ ->
+                SignatureOrMac1
+        end,
     {VerificationMethod, Algorithm} = verification_algorithm(Alg),
     case VerificationMethod of
         public_key ->
-            public_key_verify(Algorithm, Message, SignatureOrMac1, Key);
+            public_key_verify(Algorithm, Message, SignatureOrMac2, Key);
         hmac ->
-            hmac_verify(Algorithm, Message, SignatureOrMac1, Key)
+            hmac_verify(Algorithm, Message, SignatureOrMac2, Key)
     end.
 
-
 public_key_verify(Algorithm, Message, Signature, PublicKey) ->
     case public_key:verify(Message, Algorithm, Signature, PublicKey) of
         true ->
@@ -288,7 +299,6 @@ public_key_verify(Algorithm, Message, Signature, PublicKey) ->
             throw({bad_request, <<"Bad signature">>})
     end.
 
-
 hmac_verify(Algorithm, Message, HMAC, SecretKey) ->
     case hmac(Algorithm, SecretKey, Message) of
         HMAC ->
@@ -297,6 +307,19 @@ hmac_verify(Algorithm, Message, HMAC, SecretKey) ->
             throw({bad_request, <<"Bad HMAC">>})
     end.
 
+jose_to_der(Signature) ->
+    NumLen = 8 * byte_size(Signature) div 2,
+    <<R:NumLen, S:NumLen>> = Signature,
+    SigValue = #'ECDSA-Sig-Value'{r = R, s = S},
+    public_key:der_encode('ECDSA-Sig-Value', SigValue).
+
+der_to_jose(Alg, Signature) ->
+    #'ECDSA-Sig-Value'{r = R, s = S} = public_key:der_decode('ECDSA-Sig-Value', Signature),
+    Len = rs_len(Alg),
+    <<R:Len, S:Len>>.
+
+rs_len(<<"ES", SizeBin/binary>>) ->
+    binary_to_integer(SizeBin).
 
 split(EncodedToken) ->
     case binary:split(EncodedToken, <<$.>>, [global]) of
@@ -304,6 +327,8 @@ split(EncodedToken) ->
         _ -> throw({bad_request, <<"Malformed token">>})
     end.
 
+decode_passthrough(B64UrlEncoded) ->
+    B64UrlEncoded.
 
 decode_b64url_json(B64UrlEncoded) ->
     try
@@ -314,18 +339,15 @@ decode_b64url_json(B64UrlEncoded) ->
                 jiffy:decode(JsonEncoded)
         end
     catch
-        error:Error ->
-            throw({bad_request, Error})
+        _:_ ->
+            throw({bad_request, <<"Malformed token">>})
     end.
 
-
 props({Props}) ->
     Props;
-
 props(_) ->
     throw({bad_request, <<"Not an object">>}).
 
-
 assert_past(Name, Time) ->
     case Time < now_seconds() of
         true ->
@@ -342,41 +364,16 @@ assert_future(Name, Time) ->
             throw({unauthorized, <<Name/binary, " not in future">>})
     end.
 
-
 now_seconds() ->
     {MegaSecs, Secs, _MicroSecs} = os:timestamp(),
     MegaSecs * 1000000 + Secs.
 
-
 prop(Prop, Props) ->
     proplists:get_value(Prop, Props).
 
-
--ifdef(OTP_RELEASE).
-
--if(?OTP_RELEASE >= 22).
-
-% OTP >= 22
 hmac(Alg, Key, Message) ->
     crypto:mac(hmac, Alg, Key, Message).
 
--else.
-
-% OTP >= 21, < 22
-hmac(Alg, Key, Message) ->
-    crypto:hmac(Alg, Key, Message).
-
--endif. % -if(?OTP_RELEASE >= 22)
-
--else.
-
-% OTP < 21
-hmac(Alg, Key, Message) ->
-    crypto:hmac(Alg, Key, Message).
-
--endif. % -ifdef(OTP_RELEASE)
-
-
 -ifdef(TEST).
 -include_lib("eunit/include/eunit.hrl").
 
