@@ -27,9 +27,7 @@
     init/1,
     handle_call/3,
     handle_cast/2,
-    handle_info/2,
-    code_change/3,
-    terminate/2
+    handle_info/2
 ]).
 
 % config_listener api
@@ -77,12 +75,6 @@ handle_info(restart_config_listener, State) ->
 handle_info(_Msg, State) ->
     {noreply, State}.
 
-terminate(_Reason, _State) ->
-    ok.
-
-code_change(_OldVsn, State, _Extra) ->
-    {ok, State}.
-
 % config listener callback
 
 handle_config_change("jwt_keys", ConfigKey, _ConfigValue, _, _) ->
