@@ -84,10 +84,10 @@ get_usable_indexes(Db, Selector, Opts, Kind) ->
             mango_sort_error(Db, Opts);
         {UsableIndexes, _} ->
             Trace = #{
-                all_indexes => sets:from_list(ExistingIndexes),
-                global_indexes => sets:from_list(GlobalIndexes),
-                partition_indexes => sets:from_list(PartitionIndexes),
-                usable_indexes => sets:from_list(UsableIndexes),
+                all_indexes => couch_util:set_from_list(ExistingIndexes),
+                global_indexes => couch_util:set_from_list(GlobalIndexes),
+                partition_indexes => couch_util:set_from_list(PartitionIndexes),
+                usable_indexes => couch_util:set_from_list(UsableIndexes),
                 usability_map => UsabilityMap
             },
             {UsableIndexes, Trace}
@@ -544,10 +544,10 @@ t_get_usable_indexes_empty(_) ->
     ?assertThrow(Exception2, get_usable_indexes(Database, selector, Options1, find)),
     Trace =
         #{
-            all_indexes => sets:new(),
-            global_indexes => sets:new(),
-            partition_indexes => sets:new(),
-            usable_indexes => sets:new(),
+            all_indexes => couch_util:new_set(),
+            global_indexes => couch_util:new_set(),
+            partition_indexes => couch_util:new_set(),
+            usable_indexes => couch_util:new_set(),
             usability_map => []
         },
     ?assertEqual({[], Trace}, get_usable_indexes(Database, selector, Options1, explain)),
@@ -580,10 +580,10 @@ t_get_usable_indexes_regular(_) ->
         ],
     Trace =
         #{
-            all_indexes => sets:from_list(ExistingIndexes),
-            global_indexes => sets:from_list(GlobalIndexes),
-            partition_indexes => sets:from_list(PartitionIndexes),
-            usable_indexes => sets:from_list(UsableIndexes),
+            all_indexes => couch_util:set_from_list(ExistingIndexes),
+            global_indexes => couch_util:set_from_list(GlobalIndexes),
+            partition_indexes => couch_util:set_from_list(PartitionIndexes),
+            usable_indexes => couch_util:set_from_list(UsableIndexes),
             usability_map => UsabilityMap
         },
     meck:expect(ddoc_cache, open, [Database, mango_idx], meck:val({ok, ExistingIndexes})),
@@ -636,10 +636,10 @@ t_get_usable_indexes_user_specified_index(_) ->
         ],
     Trace =
         #{
-            all_indexes => sets:from_list(ExistingIndexes),
-            global_indexes => sets:from_list(GlobalIndexes),
-            partition_indexes => sets:from_list(PartitionIndexes),
-            usable_indexes => sets:from_list(UsableIndexes),
+            all_indexes => couch_util:set_from_list(ExistingIndexes),
+            global_indexes => couch_util:set_from_list(GlobalIndexes),
+            partition_indexes => couch_util:set_from_list(PartitionIndexes),
+            usable_indexes => couch_util:set_from_list(UsableIndexes),
             usability_map => UsabilityMap
         },
     meck:expect(ddoc_cache, open, [Database, mango_idx], meck:val({ok, ExistingIndexes})),
