@@ -1181,6 +1181,30 @@ cover_passthrough_test() ->
     ?assertEqual({ok, {meck_test_module, {2,1}}},
                  cover:analyze(meck_test_module, module)).
 
+cover_no_meck_original_in_cover_export_test() ->
+    {ok, _} = cover:compile("test/meck_test_module.erl"),
+
+    passthrough_test([]),
+
+    Filename =
+        lists:flatten(
+            io_lib:format(
+                "tmp_~b_~p.coverdata",
+                [rand:uniform(100_000), meck_util:original_name(meck_test_module)]
+            )
+        ),
+    try
+        ok = cover:export(Filename),
+        ok = cover:import(Filename)
+    after
+        _ = file:delete(Filename)
+    end,
+
+    ?assertNot(
+        lists:member(meck_util:original_name(meck_test_module), cover:imported_modules()),
+        "the meck generated module should not be in the exported cover data"
+    ).
+
 cover_path_test() ->
     {ok, _} = cover:compile("test/meck_test_module.erl"),
     ?assertEqual({ok, {meck_test_module, {0,3}}},
@@ -1348,31 +1372,28 @@ remote_meck_test_() ->
 
 remote_setup() ->
     [] = os:cmd("epmd -daemon"),
-    Hostname = case node() of
-      'nonode@nohost' -> "localhost";
-      _               -> test_server_sup:hoststr()
-    end,
-    Myself = list_to_atom("meck_eunit_test@" ++ Hostname),
-    net_kernel:start([Myself, shortnames]),
-    {ok, Node} = slave:start_link(list_to_atom(Hostname), meck_remote_test,
-                                  "-pa \"" ++ test_dir() ++ "\""),
+    net_kernel:start([meck_eunit_test]),
+    {ok, Pid, Node} = peer:start_link(#{
+        name => meck_remote_test,
+        args => ["-pa", test_dir()]
+    }),
     {Mod, Bin, File} = code:get_object_code(meck),
     true = rpc:call(Node, code, add_path, [filename:dirname(File)]),
     {module, Mod} = rpc:call(Node, code, load_binary, [Mod, File, Bin]),
     {module, meck_test_module} =
         rpc:call(Node, code, load_file, [meck_test_module]),
-    {Node, meck_test_module}.
+    {Pid, Node, meck_test_module}.
 
-remote_teardown({Node, _Mod}) ->
-    ok = slave:stop(Node),
+remote_teardown({Pid, _Node, _Mod}) ->
+    ok = peer:stop(Pid),
     ok = net_kernel:stop().
 
-remote_meck_({Node, Mod}) ->
+remote_meck_({_Pid, Node, Mod}) ->
     ?assertEqual(ok, rpc:call(Node, meck, new, [Mod, [no_link, non_strict]])),
     ?assertEqual(ok, rpc:call(Node, meck, expect, [Mod, test, 0, true])),
     ?assertEqual(true, rpc:call(Node, Mod, test, [])).
 
-remote_meck_cover_({Node, Mod}) ->
+remote_meck_cover_({_Pid, Node, Mod}) ->
     {ok, Mod} = cover:compile(test_file(Mod, ".erl")),
     {ok, _Nodes} = cover:start([Node]),
     ?assertEqual(ok, rpc:call(Node, meck, new, [Mod])).
