@@ -17,9 +17,7 @@
     init/1,
     handle_call/3,
     handle_cast/2,
-    handle_info/2,
-    code_change/3,
-    terminate/2
+    handle_info/2
 ]).
 
 -export([
@@ -32,12 +30,10 @@
     ready = false,
     seeds = [],
     jobref = nil,
-    % nested proplist keyed on node name
-    status = []
+    % map keyed on node name
+    status = #{}
 }).
 
--define(REPLICATION_INTERVAL, 60000).
-
 start_link() ->
     gen_server:start_link({local, ?MODULE}, ?MODULE, [], []).
 
@@ -47,8 +43,8 @@ get_seeds() ->
             [];
         List ->
             Nodes = string:tokens(List, ","),
-            Seeds = [list_to_atom(Node) || Node <- Nodes] -- [node()],
-            mem3_util:rotate_list(node(), Seeds)
+            Seeds = [list_to_atom(Node) || Node <- Nodes] -- [config:node_name()],
+            mem3_util:rotate_list(config:node_name(), Seeds)
     end.
 
 get_status() ->
@@ -56,29 +52,26 @@ get_status() ->
 
 init([]) ->
     Seeds = get_seeds(),
-    InitStatus = [{Seed, {[]}} || Seed <- Seeds],
-    State = #st{
+    Ready =
+        case Seeds of
+            [] -> true;
+            _ -> false
+        end,
+    St = #st{
         seeds = Seeds,
-        ready =
-            case Seeds of
-                [] -> true;
-                _ -> false
-            end,
+        ready = Ready,
         jobref = start_replication(Seeds),
-        status = InitStatus
+        status = maps:from_keys(Seeds, #{})
     },
-    {ok, State}.
+    {ok, St}.
 
 handle_call(get_status, _From, St) ->
-    Status =
-        {[
-            {status,
-                case St#st.ready of
-                    true -> ok;
-                    false -> seeding
-                end},
-            {seeds, {St#st.status}}
-        ]},
+    Ready =
+        case St#st.ready of
+            true -> ok;
+            false -> seeding
+        end,
+    Status = #{status => Ready, seeds => St#st.status},
     {reply, {ok, Status}, St}.
 
 handle_cast(_Msg, St) ->
@@ -92,12 +85,6 @@ handle_info({'DOWN', Ref, _, Pid, Output}, #st{jobref = {Pid, Ref}} = St) ->
 handle_info(_Msg, St) ->
     {noreply, St}.
 
-terminate(_Reason, _St) ->
-    ok.
-
-code_change(_OldVsn, St, _Extra) ->
-    {ok, St}.
-
 % internal functions
 
 start_replication([]) ->
@@ -108,16 +95,14 @@ start_replication([Seed | _]) ->
         exit({ok, Reply})
     end).
 
-update_state(State, {ok, Data}) ->
-    #st{seeds = [Current | Tail], status = Status} = State,
-    Report =
-        {[
-            {timestamp, list_to_binary(mem3_util:iso8601_timestamp())},
-            {last_replication_status, ok},
-            format_data(Data)
-        ]},
-    NewStatus = lists:ukeymerge(1, [{Current, Report}], Status),
-    Ready = is_ready(State#st.ready, Data),
+update_state(#st{} = St, {ok, Data}) ->
+    #st{seeds = [Current | Tail], status = #{} = Status} = St,
+    Report = #{
+        timestamp => list_to_binary(mem3_util:iso8601_timestamp()),
+        pending_updates => lists:foldl(fun pending_updates/2, #{}, Data),
+        last_replication_status => ok
+    },
+    Ready = is_ready(St#st.ready, Data),
     case Ready of
         true ->
             Seeds = Tail ++ [Current],
@@ -127,31 +112,29 @@ update_state(State, {ok, Data}) ->
             Seeds = [Current | Tail],
             Job = start_replication([Current | Tail])
     end,
-    State#st{
+    St#st{
         seeds = Seeds,
         jobref = Job,
         ready = Ready,
-        status = NewStatus
+        status = Status#{Current => Report}
     };
-update_state(State, {_Error, _Stack}) ->
-    #st{seeds = [Current | Tail], status = Status} = State,
-    Report =
-        {[
-            {timestamp, list_to_binary(mem3_util:iso8601_timestamp())},
-            {last_replication_status, error}
-        ]},
-    NewStatus = lists:ukeymerge(1, [{Current, Report}], Status),
+update_state(#st{} = St, {_Error, _Stack}) ->
+    #st{seeds = [Current | Tail], status = #{} = Status} = St,
+    Report = #{
+        timestamp => list_to_binary(mem3_util:iso8601_timestamp()),
+        last_replication_status => error
+    },
     Seeds = Tail ++ [Current],
     if
-        not State#st.ready ->
+        not St#st.ready ->
             erlang:send_after(1000, self(), start_replication);
         true ->
             ok
     end,
-    State#st{
+    St#st{
         seeds = Seeds,
         jobref = nil,
-        status = NewStatus
+        status = Status#{Current => Report}
     }.
 
 is_ready(true, _) ->
@@ -159,18 +142,12 @@ is_ready(true, _) ->
 is_ready(false, Data) ->
     lists:all(fun({_DbName, Pending}) -> Pending =:= {ok, 0} end, Data).
 
-format_data(Data) ->
-    Formatted = lists:map(
-        fun({DbName, Status}) ->
-            case Status of
-                {ok, Pending} when is_number(Pending) ->
-                    {DbName, Pending};
-                {error, Tag} ->
-                    {DbName, list_to_binary(io_lib:format("~p", [Tag]))};
-                _Else ->
-                    {DbName, unknown_error}
-            end
-        end,
-        Data
-    ),
-    {pending_updates, {Formatted}}.
+pending_updates({DbName, Status}, #{} = Acc) ->
+    case Status of
+        {ok, Pending} when is_number(Pending) ->
+            Acc#{DbName => Pending};
+        {error, Tag} ->
+            Acc#{DbName => list_to_binary(io_lib:format("~p", [Tag]))};
+        _Else ->
+            Acc#{DbName => unknown_error}
+    end.
