@@ -136,11 +136,12 @@ ping_nodes_test(_) ->
             {n1, {nodedown, n1}},
             {n2, {nodedown, n2}}
         ],
-        couch_debug:ping_nodes()
+        couch_debug:ping_live_cluster_nodes()
     ),
     ?assertEqual({nodedown, n3}, couch_debug:ping(n3, 100)).
 
 dead_nodes_test(_) ->
     meck:expect(mem3, nodes, 0, [n1, n2, n3]),
     meck:expect(mem3_util, live_nodes, 0, [n1, n2]),
-    ?assertEqual([n3], couch_debug:dead_nodes()).
+    Node = node(),
+    ?assertEqual([{Node, [n3]}], couch_debug:dead_nodes()).
