@@ -376,7 +376,7 @@ add_node_int(Options, true) ->
     end.
 
 get_port(Port) when is_integer(Port) ->
-    list_to_binary(integer_to_list(Port));
+    integer_to_binary(Port);
 get_port(Port) when is_list(Port) ->
     list_to_binary(Port);
 get_port(Port) when is_binary(Port) ->
